<?php

declare(strict_types=1);

namespace Kylin\Hr\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

/**
 * 工资条明细模型
 *
 * 管理工资条中的各项明细，如基本工资、绩效、补贴、扣款等。
 *
 * @property string $item_name 项目名称
 * @property float  $amount    金额
 * @property string $type      项目类型
 */
class SalarySlipItem extends Model
{
    protected $fillable = [
        'salary_slip_id',
        'item_id',
        'item_name',
        'amount',
    ];

    protected function casts(): array
    {
        return [
            'amount' => 'decimal:2',
        ];
    }

    public function salarySlip(): BelongsTo
    {
        return $this->belongsTo(SalarySlip::class);
    }
}
