<?php

declare(strict_types=1);

namespace Kylin\Hr\Enums;

/**
 * 用工类型枚举
 */
enum EmploymentType: string
{
    case FullTime = 'full_time';    // 全职
    case PartTime = 'part_time';    // 兼职
    case Intern = 'intern';         // 实习生
    case Outsource = 'outsource';   // 外包

    /**
     * 获取标签
     */
    public function label(): string
    {
        return match ($this) {
            self::FullTime  => '全职',
            self::PartTime  => '兼职',
            self::Intern    => '实习生',
            self::Outsource => '外包',
        };
    }
}
