<?php

declare(strict_types=1);

namespace Kylin\Hr\Enums;

/**
 * 性别枚举
 */
enum Gender: string
{
    case Male = 'male';
    case Female = 'female';

    /**
     * 获取标签
     */
    public function label(): string
    {
        return match ($this) {
            self::Male   => '男',
            self::Female => '女',
        };
    }
}
