<?php

declare(strict_types=1);

namespace Kylin\Hr\Enums;

/**
 * 合同类型枚举
 */
enum ContractType: int
{
    case FixedTerm = 1;       // 固定期限
    case OpenEnded = 2;       // 无固定期限
    case PartTime = 3;        // 非全日制
    case Internship = 4;      // 实习协议
    case Outsourcing = 5;     // 劳务外包

    /**
     * 获取标签
     */
    public function label(): string
    {
        return match ($this) {
            self::FixedTerm   => '固定期限',
            self::OpenEnded   => '无固定期限',
            self::PartTime    => '非全日制',
            self::Internship  => '实习协议',
            self::Outsourcing => '劳务外包',
        };
    }
}
